MinimalDistance

Struct MinimalDistance 

pub struct MinimalDistance<'a> { /* private fields */ }
Calculation of minimum distance from one part of the grammar to another. Similar to multi-source shortest path search in a graph.

Implementations

Source

impl<'a> MinimalDistance<'a>

pub fn new(grammar: &'a Cfg) -> Self

Returns a new MinimalDistance for a grammar.

pub fn distances(&self) -> &[Vec<Option<u32>>]

Returns distances in order respective to the order of rule iteration.

pub fn minimal_distances( &mut self, dots: &[(usize, usize)], direction: DistanceDirection, ) -> &[Vec<Option<u32>>]

Calculates minimal distance from one parts of the grammar to others. Returns distances in order respective to the order of rule iteration.